pocketpose.version - PocketPose 0.0.1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `pocketpose.version`

## Module Contents

### Functions

`parse_version_info`(version_str) | Parse a version string into a tuple.

### Attributes

`__version__` |
`short_version` |
`version_info` |

pocketpose.version.__version__ = '0.0.1'

pocketpose.version.short_version

pocketpose.version.parse_version_info(version_str)

  Parse a version string into a tuple.

  Args:

    version_str (str): The version string.

  Returns:
    tuple[int | str]: The version info, e.g., “1.3.0” is parsed into

      (1, 3, 0), and “2.0.0rc1” is parsed into (2, 0, 0, ‘rc1’).

pocketpose.version.version_info